@@ -82,8 +82,8 @@ func (g *Generator) collectData() error {
 		if cachedTag != "" {
 			// Get the current latest tag from git
 			currentTag, err := g.gitWalker.GetLatestTag()
-			if err == nil && currentTag == cachedTag {
-				// Same tag - load cached data and walk commits since tag for "Unreleased"
+			if err == nil {
+				// Load cached data - we can use it even if there are new tags
 				cachedVersions, err := g.cache.GetVersions()
 				if err == nil && len(cachedVersions) > 0 {
 					g.versions = cachedVersions
@@ -97,7 +97,30 @@ func (g *Generator) collectData() error {
 						}
 					}
 
-					// Walk commits since the latest tag to get new unreleased commits
+					// If we have new tags since cache, process the new versions only
+					if currentTag != cachedTag {
+						fmt.Fprintf(os.Stderr, "Processing new versions since %s...\n", cachedTag)
+						newVersions, err := g.gitWalker.WalkHistorySinceTag(cachedTag)
+						if err != nil {
+							fmt.Fprintf(os.Stderr, "Warning: Failed to walk history since tag %s: %v\n", cachedTag, err)
+						} else {
+							// Merge new versions into cached versions (only add if not already cached)
+							for name, version := range newVersions {
+								if name != "Unreleased" { // Handle Unreleased separately
+									if existingVersion, exists := g.versions[name]; !exists {
+										g.versions[name] = version
+									} else {
+										// Update existing version with new PR numbers if they're missing
+										if len(existingVersion.PRNumbers) == 0 && len(version.PRNumbers) > 0 {
+											existingVersion.PRNumbers = version.PRNumbers
+										}
+									}
+								}
+							}
+						}
+					}
+
+					// Always update Unreleased section with latest commits
 					unreleasedVersion, err := g.gitWalker.WalkCommitsSinceTag(currentTag)
 					if err != nil {
 						fmt.Fprintf(os.Stderr, "Warning: Failed to walk commits since tag %s: %v\n", currentTag, err)
@@ -110,6 +133,29 @@ func (g *Generator) collectData() error {
 						g.versions["Unreleased"] = unreleasedVersion
 					}
 
+					// Save any new versions to cache (after potential AI processing)
+					if currentTag != cachedTag {
+						for _, version := range g.versions {
+							// Skip versions that were already cached and Unreleased
+							if version.Name != "Unreleased" {
+								if err := g.cache.SaveVersion(version); err != nil {
+									fmt.Fprintf(os.Stderr, "Warning: Failed to save version to cache: %v\n", err)
+								}
+
+								for _, commit := range version.Commits {
+									if err := g.cache.SaveCommit(commit, version.Name); err != nil {
+										fmt.Fprintf(os.Stderr, "Warning: Failed to save commit to cache: %v\n", err)
+									}
+								}
+							}
+						}
+
+						// Update the last processed tag
+						if err := g.cache.SetLastProcessedTag(currentTag); err != nil {
+							fmt.Fprintf(os.Stderr, "Warning: Failed to update last processed tag: %v\n", err)
+						}
+					}
+
 					return nil
 				}
 			}
@@ -164,8 +210,26 @@ func (g *Generator) fetchPRs() error {
 		lastSync, _ = g.cache.GetLastPRSync()
 	}
 
+	// Check if we need to sync for missing PRs
+	missingPRs := false
+	for _, version := range g.versions {
+		for _, prNum := range version.PRNumbers {
+			if _, exists := g.prs[prNum]; !exists {
+				missingPRs = true
+				break
+			}
+		}
+		if missingPRs {
+			break
+		}
+	}
+
+	if missingPRs {
+		fmt.Fprintf(os.Stderr, "Full sync triggered due to missing PRs in cache.\n")
+	}
 	// If we have never synced or it's been more than 24 hours, do a full sync
-	needsSync := lastSync.IsZero() || time.Since(lastSync) > 24*time.Hour || g.cfg.ForcePRSync
+	// Also sync if we have versions with PR numbers that aren't cached
+	needsSync := lastSync.IsZero() || time.Since(lastSync) > 24*time.Hour || g.cfg.ForcePRSync || missingPRs
 
 	if !needsSync {
 		fmt.Fprintf(os.Stderr, "Using cached PR data (last sync: %s)\n", lastSync.Format("2006-01-02 15:04:05"))
@@ -298,6 +362,7 @@ func (g *Generator) formatVersion(version *git.Version) string {
 			}
 		}
 
+		// For released versions, if we have cached AI summary, use it!
 		if version.Name != "Unreleased" && version.AISummary != "" {
 			fmt.Fprintf(os.Stderr, "✅ %s already summarized (skipping)\n", version.Name)
 			sb.WriteString(version.AISummary)
@@ -529,8 +594,6 @@ func normalizeLineEndings(content string) string {
 }
 
 func (g *Generator) formatCommitMessage(message string) string {
-	prefixes := []string{"fix:", "feat:", "docs:", "style:", "refactor:",
-		"test:", "chore:", "perf:", "ci:", "build:", "revert:", "# docs:"}
 	strings_to_remove := []string{
 		"### CHANGES\n", "## CHANGES\n", "# CHANGES\n",
 		"...\n", "---\n", "## Changes\n", "## Change",
@@ -543,13 +606,6 @@ func (g *Generator) formatCommitMessage(message string) string {
 	// No hard tabs
 	message = strings.ReplaceAll(message, "\t", " ")
 
-	for _, prefix := range prefixes {
-		if strings.HasPrefix(strings.ToLower(message), prefix) {
-			message = strings.TrimSpace(message[len(prefix):])
-			break
-		}
-	}
-
 	if len(message) > 0 {
 		message = strings.ToUpper(message[:1]) + message[1:]
 	}
