@@ -79,7 +79,9 @@ func (o *Chatter) Send(request *domain.ChatRequest, opts *domain.ChatOptions) (s
 
 		for response := range responseChan {
 			message += response
-			fmt.Print(response)
+			if !opts.SuppressThink {
+				fmt.Print(response)
+			}
 		}
 
 		// Wait for goroutine to finish
@@ -101,6 +103,10 @@ func (o *Chatter) Send(request *domain.ChatRequest, opts *domain.ChatOptions) (s
 		}
 	}
 
+	if opts.SuppressThink {
+		message = domain.StripThinkBlocks(message, opts.ThinkStartTag, opts.ThinkEndTag)
+	}
+
 	if message == "" {
 		session = nil
 		err = fmt.Errorf("empty response")
